from setuptools import setup

des = "\n-----Offense without defense, \n\tunparalleled in the world.-----\n\nWelcome to the universe of N1nEmAn.\n  To find detailed usage instructions for evilblade,\n     please visit cnblogs.com/9man."

setup(
    name='evilblade',
    version='1.1.0',
    description='7 N1nEmAn\'s evilblade!!my blog:cnblogs.com/9man',
    packages=['evilblade'],
    long_description=des,
)
